@@ -1,7 +1,7 @@
 get_facebook <-
 function(links, sleep.time=0) {
     fbk.response <- data.frame()
-    fbk.call <- paste0("https://api.facebook.com/method/links.getStats?urls=",links,"&format=json")
+    fbk.call <- paste0("http://graph.facebook.com/?fields=share&id=",links,"&format=json")
     if(.Platform$OS.type == "windows") { if(!file.exists("cacert.perm")) download.file(url="https://curl.haxx.se/ca/cacert.pem", destfile="cacert.perm") }
     if(.Platform$OS.type == "windows") { api_scrapper <- function(x) try(RCurl::getURL(x, cainfo = "cacert.perm", timeout = 240, ssl.verifypeer = FALSE)) } else { 
     api_scrapper <- function(x) try(RCurl::getURL(x, timeout = 240, ssl.verifypeer = FALSE)) }
